@@ -64,10 +64,6 @@ sub del {
 }
 
 sub run {
-    my @caller = caller;
-    if ( $caller[0] =~ /Plack::Sandbox/ ) {
-        return $app;
-    }
     $app->run;
 }
 
@@ -205,7 +201,7 @@ This a full alias for C<$self>. It is the application object, and an
 instance of the C<Kelp> class. You can use it for anything you would use
 C<$self> inside a route.
 
-    route '/yo' => sub {
+    route '/die' => sub {
         app->res->code(500);
     };
 
@@ -316,27 +312,6 @@ currently loaded template module.
 
 Creates and returns a PSGI ready subroutine, and makes the app ready for C<Plack>.
 
-=head1 TESTING
-
-When writing a C<Kelp::Less> app, we don't have a separate class to initialize as we
-please and feed into a L<Kelp::Test> object. In this case, the C<Kelp::Test>
-object can be initialized with the name of the C<PSGI> file in the C<psgi> argument.
-
-    # t/main.t
-    use Kelp::Test;
-
-    my $t = Kelp::Test->new( psgi => 'app.psgi' );
-    # Do some tests ...
-
-Since you don't have control over the creation of the C<Kelp> object, if you
-need to specify a different mode for testing, you can use the C<PLACK_ENV>
-environmental variable:
-
-    > PLACK_ENV=test prove -l
-
-This will enable the C<conf/config_test.pl> configuration, which you should
-tailor to your testing needs.
-
 =head1 ACKNOWLEDGEMENTS
 
 This module's interface was inspired by L<Dancer>, which in its turn was
